package com.gxzc.zen.web.sys.controller

import com.baomidou.kisso.annotation.Action
import com.baomidou.kisso.annotation.Login
import com.gxzc.zen.api.sys.model.SysDic
import com.gxzc.zen.api.sys.model.SysParam
import com.gxzc.zen.api.sys.service.ISysParamService
import com.gxzc.zen.common.base.BaseController
import com.gxzc.zen.common.config.response.annotation.ZenResponseFilter
import com.gxzc.zen.common.dto.ResponseDto
import org.slf4j.LoggerFactory
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.http.ResponseEntity
import org.springframework.web.bind.annotation.*

/**
 * 系统参数控制器
 * @author NorthLan
 * @date 2018/3/19
 * @url https://noahlan.com
 */
@RestController
@RequestMapping("sys/param")
class SysParamController : BaseController() {
    companion object {
        private val logger = LoggerFactory.getLogger(SysParamController::class.java)
    }

    @Autowired
    private lateinit var sysParamService: ISysParamService

    @GetMapping("/list")
    @Login(action = Action.Skip)
    @ZenResponseFilter(type = SysDic::class, filter = ["createBy", "updateBy", "createTime", "updateTime"])
    fun getList(): ResponseEntity<*> {
        return ResponseEntity.ok(ResponseDto().apply {
            data = sysParamService.getListCacheable()
        })
    }

    @GetMapping("{key}")
    @ZenResponseFilter(type = SysDic::class, filter = ["createBy", "updateBy", "createTime", "updateTime"])
    fun get(@PathVariable key: String): ResponseEntity<*> {
        return ResponseEntity.ok(ResponseDto().apply {
            data = sysParamService.getListByKey(key)
        })
    }

    @PutMapping("{key}")
    @ZenResponseFilter(type = SysDic::class, filter = ["createBy", "updateBy", "createTime", "updateTime"])
    fun putDic(@PathVariable key: String, @RequestBody data: SysParam): ResponseEntity<*> {
        return ResponseEntity.ok(ResponseDto().apply {
            this.data = sysParamService.modifySysDic(data)
        })
    }
}